@@ -4,6 +4,8 @@
 //! The `libspa` crate provides a high-level API to interact with
 //! [libspa](https://gitlab.freedesktop.org/pipewire/pipewire/-/tree/master/doc/spa).
 
+pub use spa_sys as sys;
+
 pub mod data;
 pub mod dict;
 pub use dict::*;
@@ -17,6 +19,8 @@ pub mod pod;
 pub mod utils;
 pub use direction::*;
 pub mod flags;
+pub mod format;
+pub mod param;
 
 /// prelude module re-exporing all the traits providing public API.
 pub mod prelude {
